@@ -1,4 +1,27 @@
 #!/usr/bin/env python
+"""
+Usage: ``python -m pysb.tools.render_species mymodel.py > mymodel.dot``
+
+Renders the species from a model into the "dot" graph format which can be
+visualized with Graphviz.
+
+To create a PDF from the .dot file, use the Graphviz tools in the following
+command pipeline::
+
+    ccomps -x mymodel.dot | dot | gvpack -m0 | neato -n2 -T pdf -o mymodel.pdf
+
+You can also change the "dot" command to "circo" or "sfdp" for a different type
+of layout. Note that you can pipe the output of render_species straight into a
+Graphviz command pipeline without creating an intermediate .dot file, which is
+especially helpful if you are making continuous changes to the model and need to
+visualize your changes repeatedly::
+
+    python -m pysb.tools.render_species mymodel.py | ccomps -x | dot |
+      gvpack -m0 | neato -n2 -T pdf -o mymodel.pdf
+
+Note that some PDF viewers will auto-reload a changed PDF, so you may not even
+need to manually reopen it every time you rerun the tool.
+"""
 
 import sys
 import os
@@ -7,20 +30,40 @@ import pygraphviz
 import pysb.bng
 
 def run(model):
+    """
+    Render the species from a model into the "dot" graph format.
+
+    Parameters
+    ----------
+    model : pysb.core.Model
+        The model to render.
+
+    Returns
+    -------
+    string
+        The dot format output.
+    """
+
     pysb.bng.generate_equations(model)
-    graph = pygraphviz.AGraph(name="%s species" % model.name, rankdir="LR", fontname='Arial')
+    graph = pygraphviz.AGraph(name="%s species" % model.name, rankdir="LR",
+                              fontname='Arial')
     graph.edge_attr.update(fontname='Arial', fontsize=8)
     for si, cp in enumerate(model.species):
         sgraph_name = 'cluster_s%d' % si
-        cp_label = re.sub(r'% ', '%<br align="left"/>', str(cp)) + '<br align="left"/>'
-        sgraph_label = '<<font point-size="10" color="blue">s%d</font><br align="left"/><font face="Consolas" point-size="6">%s</font>>' % (si, cp_label)
+        cp_label = re.sub(r'% ', '%<br align="left"/>',
+                          str(cp)) + '<br align="left"/>'
+        sgraph_label = '<<font point-size="10" color="blue">s%d</font>' \
+                       '<br align="left"/>' \
+                       '<font face="Consolas" point-size="6">%s</font>>' % \
+                       (si, cp_label)
         sgraph = graph.add_subgraph(name=sgraph_name, label=sgraph_label,
                                     color="gray75", sortv=sgraph_name)
         bonds = {}
         for mi, mp in enumerate(cp.monomer_patterns):
             monomer_node = '%s_%d' % (sgraph_name, mi)
             monomer_label = '<<table border="0" cellborder="1" cellspacing="0">'
-            monomer_label += '<tr><td bgcolor="#a0ffa0"><b>%s</b></td></tr>' % mp.monomer.name
+            monomer_label += '<tr><td bgcolor="#a0ffa0"><b>%s</b></td></tr>' % \
+                             mp.monomer.name
             for site in mp.monomer.sites:
                 site_state = None
                 cond = mp.site_conditions[site]
@@ -31,7 +74,8 @@ def run(model):
                 site_label = site
                 if site_state is not None:
                     site_label += '=<font color="purple">%s</font>' % site_state
-                monomer_label += '<tr><td port="%s">%s</td></tr>' % (site, site_label)
+                monomer_label += '<tr><td port="%s">%s</td></tr>' % \
+                                 (site, site_label)
             for site, value in mp.site_conditions.items():
                 site_bonds = []  # list of bond numbers
                 if isinstance(value, int):
@@ -52,30 +96,7 @@ def run(model):
                             headport=port_names[1], label=str(bi))
     return graph.string()
 
-
-usage = """
-Usage: python -m pysb.tools.render_species mymodel.py > mymodel.dot
-
-Renders the species from a model into the "dot" graph format which can be
-visualized with Graphviz.
-
-To create a PDF from the .dot file, use the Graphviz tools in the following
-command pipeline:
-
-    ccomps -x mymodel.dot | dot | gvpack -m0 | neato -n2 -T pdf -o mymodel.pdf
-
-You can also change the "dot" command to "circo" or "sfdp" for a different type
-of layout. Note that you can pipe the output of render_species straight into a
-Graphviz command pipeline without creating an intermediate .dot file, which is
-especially helpful if you are making continuous changes to the model and need to
-visualize your changes repeatedly:
-
-    python -m pysb.tools.render_species mymodel.py | ccomps -x | dot |
-      gvpack -m0 | neato -n2 -T pdf -o mymodel.pdf
-
-Note that some PDF viewers will auto-reload a changed PDF, so you may not even
-need to manually reopen it every time you rerun the tool.
-"""
+usage = __doc__
 usage = usage[1:]  # strip leading newline
 
 if __name__ == '__main__':
@@ -92,8 +113,9 @@ if __name__ == '__main__':
     model_name = re.sub(r'\.py$', '', os.path.basename(model_filename))
     # import it
     try:
-        # FIXME if the model has the same name as some other "real" module which we use,
-        # there will be trouble (use the imp package and import as some safe name?)
+        # FIXME if the model has the same name as some other "real" module
+        # which we use, there will be trouble (use the imp package and import
+        # as some safe name?)
         model_module = __import__(model_name)
     except StandardError as e:
         print "Error in model script:\n"
